@@ -2,10 +2,11 @@ import sys
 
 from shopyoapi.cmd import new_project
 
-def main(args):
+def main():
+    args = sys.argv
     if args[1] == "new" and len(args) == 4:
         new_project(args[2], args[3])
 
 
 if __name__ == "__main__":
-    main(sys.argv)
\ No newline at end of file
+    main()
\ No newline at end of file
