@@ -11,6 +11,7 @@ from shopyoapi.cmd import new_project
 from shopyoapi.cmd import clean
 from shopyoapi.cmd import initialise
 from shopyoapi.cmd import create_module
+from shopyoapi.database import autoload_models
 
 migrate = Migrate(app, db, compare_type=True)
 manager = Manager(app)
@@ -30,6 +31,7 @@ def custom_commands(args):
     # non migration commands
     if args[1] != "db":
         if args[1] == "initialise":
+            autoload_models()
             initialise()
         elif args[1] == "clean":
             clean()
@@ -45,6 +47,8 @@ def custom_commands(args):
         elif args[1] == 'startapp' and args[2]:
             create_module(args[2])
         sys.exit()
+    elif args[1] == "db":
+        autoload_models()
 
 
 if __name__ == "__main__":
